@@ -3,6 +3,7 @@ package m
 import (
 	"fmt"
 	"regexp"
+	"runtime/debug"
 	"strings"
 	"time"
 
@@ -322,6 +323,10 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 	p.marks = make(map[rune]scrollPosition)
 
 	go func() {
+		defer func() {
+			panicHandler("StartPaging()/moreLinesAvailable", recover(), debug.Stack())
+		}()
+
 		for range p.reader.moreLinesAdded {
 			// Notify the main loop about the new lines so it can show them
 			screen.Events() <- eventMoreLinesAvailable{}
@@ -337,6 +342,10 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 	}()
 
 	go func() {
+		defer func() {
+			panicHandler("StartPaging()/spinner", recover(), debug.Stack())
+		}()
+
 		// Spin the spinner as long as contents is still loading
 		spinnerFrames := [...]string{"/.\\", "-o-", "\\O/", "| |"}
 		spinnerIndex := 0
@@ -359,6 +368,10 @@ func (p *Pager) StartPaging(screen twin.Screen, chromaStyle *chroma.Style, chrom
 	}()
 
 	go func() {
+		defer func() {
+			panicHandler("StartPaging()/maybeDone", recover(), debug.Stack())
+		}()
+
 		for range p.reader.maybeDone {
 			screen.Events() <- eventMaybeDone{}
 		}
