@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"os"
 	"regexp"
+	"runtime/debug"
 	"strconv"
 	"strings"
 	"unicode/utf8"
@@ -96,7 +97,7 @@ type UnixScreen struct {
 	ttyOut        *os.File
 	oldTtyOutMode uint32 //nolint Windows only
 
-	terminalColorCount ColorType
+	terminalColorCount ColorCount
 }
 
 // Example event: "\x1b[<65;127;41M"
@@ -121,15 +122,15 @@ func NewScreen() (Screen, error) {
 }
 
 func NewScreenWithMouseMode(mouseMode MouseMode) (Screen, error) {
-	terminalColorCount := ColorType24bit
+	terminalColorCount := ColorCount24bit
 	if os.Getenv("COLORTERM") != "truecolor" && strings.Contains(os.Getenv("TERM"), "256") {
 		// Covers "xterm-256color" as used by the macOS Terminal
-		terminalColorCount = ColorType256
+		terminalColorCount = ColorCount256
 	}
-	return NewScreenWithMouseModeAndColorType(mouseMode, terminalColorCount)
+	return NewScreenWithMouseModeAndColorCount(mouseMode, terminalColorCount)
 }
 
-func NewScreenWithMouseModeAndColorType(mouseMode MouseMode, terminalColorCount ColorType) (Screen, error) {
+func NewScreenWithMouseModeAndColorCount(mouseMode MouseMode, terminalColorCount ColorCount) (Screen, error) {
 	if !term.IsTerminal(int(os.Stdout.Fd())) {
 		return nil, fmt.Errorf("stdout (fd=%d) must be a terminal for paging to work", os.Stdout.Fd())
 	}
@@ -179,7 +180,13 @@ func NewScreenWithMouseModeAndColorType(mouseMode MouseMode, terminalColorCount
 
 	screen.hideCursor(true)
 
-	go screen.mainLoop()
+	go func() {
+		defer func() {
+			panicHandler("NewScreenWithMouseModeAndColorCount()/mainLoop()", recover(), debug.Stack())
+		}()
+
+		screen.mainLoop()
+	}()
 
 	return &screen, nil
 }
@@ -407,7 +414,7 @@ func (screen *UnixScreen) mainLoop() {
 		}
 
 		// We only expect this on entry, it's requested right before we start
-		// the main loop in NewScreenWithMouseModeAndColorType().
+		// the main loop in NewScreenWithMouseModeAndColorCount().
 		expectingTerminalBackgroundColor = false
 
 		if count > maxBytesRead {
@@ -651,7 +658,7 @@ func (screen *UnixScreen) Clear() {
 
 // Returns the rendered line, plus how many information carrying cells went into
 // it
-func renderLine(row []Cell, terminalColorCount ColorType) (string, int) {
+func renderLine(row []Cell, terminalColorCount ColorCount) (string, int) {
 	// Strip trailing whitespace
 	lastSignificantCellIndex := len(row) - 1
 	for ; lastSignificantCellIndex >= 0; lastSignificantCellIndex-- {
