@@ -3,6 +3,7 @@ package twin
 import (
 	"io"
 	"os"
+	"runtime/debug"
 	"strings"
 	"testing"
 	"time"
@@ -64,7 +65,7 @@ func TestRenderLine(t *testing.T) {
 		},
 	}
 
-	rendered, count := renderLine(row, ColorType16)
+	rendered, count := renderLine(row, ColorCount16)
 	assert.Equal(t, count, 2)
 	reset := "[m"
 	reversed := "[7m"
@@ -79,7 +80,7 @@ func TestRenderLine(t *testing.T) {
 func TestRenderLineEmpty(t *testing.T) {
 	row := []Cell{}
 
-	rendered, count := renderLine(row, ColorType16)
+	rendered, count := renderLine(row, ColorCount16)
 	assert.Equal(t, count, 0)
 
 	// All lines are expected to stand on their own, so we always need to clear
@@ -95,7 +96,7 @@ func TestRenderLineLastReversed(t *testing.T) {
 		},
 	}
 
-	rendered, count := renderLine(row, ColorType16)
+	rendered, count := renderLine(row, ColorCount16)
 	assert.Equal(t, count, 1)
 	reset := "[m"
 	reversed := "[7m"
@@ -113,7 +114,7 @@ func TestRenderLineLastNonSpace(t *testing.T) {
 		},
 	}
 
-	rendered, count := renderLine(row, ColorType16)
+	rendered, count := renderLine(row, ColorCount16)
 	assert.Equal(t, count, 1)
 	reset := "[m"
 	clearToEol := "[K"
@@ -134,7 +135,7 @@ func TestRenderLineLastReversedPlusTrailingSpace(t *testing.T) {
 		},
 	}
 
-	rendered, count := renderLine(row, ColorType16)
+	rendered, count := renderLine(row, ColorCount16)
 	assert.Equal(t, count, 1)
 	reset := "[m"
 	reversed := "[7m"
@@ -156,7 +157,7 @@ func TestRenderLineOnlyTrailingSpaces(t *testing.T) {
 		},
 	}
 
-	rendered, count := renderLine(row, ColorType16)
+	rendered, count := renderLine(row, ColorCount16)
 	assert.Equal(t, count, 0)
 
 	// All lines are expected to stand on their own, so we always need to clear
@@ -172,7 +173,7 @@ func TestRenderLineLastReversedSpaces(t *testing.T) {
 		},
 	}
 
-	rendered, count := renderLine(row, ColorType16)
+	rendered, count := renderLine(row, ColorCount16)
 	assert.Equal(t, count, 1)
 	reset := "[m"
 	reversed := "[7m"
@@ -189,7 +190,7 @@ func TestRenderLineNonPrintable(t *testing.T) {
 		},
 	}
 
-	rendered, count := renderLine(row, ColorType16)
+	rendered, count := renderLine(row, ColorCount16)
 	assert.Equal(t, count, 1)
 	reset := "[m"
 	white := "[37m"
@@ -210,7 +211,7 @@ func TestRenderHyperlinkAtEndOfLine(t *testing.T) {
 		},
 	}
 
-	rendered, count := renderLine(row, ColorType16)
+	rendered, count := renderLine(row, ColorCount16)
 	assert.Equal(t, count, 1)
 
 	assert.Equal(t,
@@ -235,7 +236,7 @@ func TestMultiCharHyperlink(t *testing.T) {
 		},
 	}
 
-	rendered, count := renderLine(row, ColorType16)
+	rendered, count := renderLine(row, ColorCount16)
 	assert.Equal(t, count, 3)
 
 	assert.Equal(t,
@@ -269,6 +270,10 @@ func TestInterruptableReader_blockedOnRead(t *testing.T) {
 	}
 	readResultChan := make(chan readResult)
 	go func() {
+		defer func() {
+			panicHandler("TestInterruptableReader_blockedOnRead()", recover(), debug.Stack())
+		}()
+
 		buffer := make([]byte, 1)
 		n, err := testMe.Read(buffer)
 		readResultChan <- readResult{n, err}
